@@ -46,10 +46,18 @@ if host == 'galactica' or host == 'roma': #proycon's laptop/server
     PORT = 9001
     BINDIR = "/home/proycon/local/bin/"
 elif host == 'applejack': #Nijmegen
-    CLAMDIR = "/scratch2/www/webservices-lst/live/repo/clam"
-    ROOT = "/scratch2/www/webservices-lst/live/writable/ucto/"
-    HOST = "webservices-lst.science.ru.nl"
-    PORT = 80
+    if not 'CLAMTEST' in environ:
+        #live production environment/
+        CLAMDIR = "/scratch2/www/webservices-lst/live/repo/clam"
+        ROOT = "/scratch2/www/webservices-lst/live/writable/ucto/"
+        HOST = "webservices-lst.science.ru.nl"
+        PORT = 80    
+    else:
+        #test environment
+        CLAMDIR = "/scratch2/www/webservices-lst/test/repo/clam"
+        ROOT = "/scratch2/www/webservices-lst/test/writable/ucto/"
+        HOST = "webservices-lst.science.ru.nl"
+        PORT = 81        
     URLPREFIX = "ucto"
     BINDIR = "/vol/customopt/uvt-ru/bin/"    
     USERS_MYSQL = {
@@ -115,12 +123,14 @@ PROFILES = [
             MSWordConverter(id='mswordconv',label='Convert from MS Word Document'),
             CharEncodingConverter(id='latin1',label='Convert from Latin-1 (iso-8859-1)',charset='iso-8859-1'),
             CharEncodingConverter(id='latin9',label='Convert from Latin-9 (iso-8859-15)',charset='iso-8859-15'),
+            extension='txt',
             multi=True,
         ),
         ParameterCondition(xml=True,
         then=OutputTemplate('foliatokoutput', FoLiAXMLFormat, "Tokenised Text Document (FoLiA XML)",
                 SetMetaField('tokenisation','ucto'),
                 copymetadata=True,
+                removeextension='txt',
                 extension='xml',
                 multi=True,                
              ),
@@ -136,6 +146,7 @@ PROFILES = [
                     then=SetMetaField('uppercase','yes')
                 ),
                 copymetadata=True,
+                removeextension='txt',
                 extension='vtok',
                 multi=True,
             ),
@@ -150,6 +161,7 @@ PROFILES = [
                     then=SetMetaField('uppercase','yes')
                 ),
                 copymetadata=True,
+                removeextension='txt',
                 extension='tok',
                 multi=True,
             )
