@@ -32,6 +32,9 @@ import clam.common.status
 import clam.common.parameters
 import clam.common.formats
 
+#make a shortcut to this function
+shellsafe = clam.common.data.shellsafe
+
 
 #this script takes three arguments: $DATAFILE $STATUSFILE $OUTPUTDIRECTORY
 datafile = sys.argv[1]
@@ -75,8 +78,9 @@ for inputfile in clamdata.input:
     if isinstance(inputfile.metadata, clam.common.formats.PlainTextFormat) or isinstance(inputfile.metadata, clam.common.formats.TokenizedTextFormat): #if the input file is a plain text format
         print "\tProcessing " + str(inputfile)
         clam.common.status.write(statusfile, "Processing " + os.path.basename(str(inputfile)) + "...")
-        #invoke 'rev' through the shell to reverse the input
-        os.system("rev " + str(inputfile) + " > " + outputdir + os.path.basename(str(inputfile)))
+
+        #invoke 'rev' through the shell to reverse the input, note the use of the shellsafe() function that wraps our input in the specified quotes (second parameter) and makes sure the value doesn't break out of the quoted environment!
+        os.system("rev " + shellsafe(str(inputfile),'"') + " > " + shellsafe(outputdir + os.path.basename(str(inputfile))),'"')
     else:
         print "\tSkipping " + str(inputfile)
         clam.common.status.write(statusfile, "Skipping " + os.path.basename(str(inputfile)) + ", invalid format")
